import { BasicPageParams, BasicFetchResult } from '@/api/model/baseModel';

export type AccountParams = BasicPageParams & {
  account?: string;
  nickname?: string;
  [key: string]: any;
};

export type RoleParams = {
  roleName?: string;
  status?: string;
};

// 创建字典查询参数
export type DictParams = {
  dictName?: string;
  flag?: number;
};
export type RolePageParams = BasicPageParams & RoleParams;
// 创建字典分页查询参数
export type DictPageParams = BasicPageParams & RoleParams;
// 创建字典路由跳转后查询参数
export type DictRouteParams = {
  businessId?: number;
};
// 创建字典新增参数
export type DictAddParams = {
  dictName?: string;
  dictType?: string;
  dataId?: string;
  parentId?: string;
  status?: string;
  flag?: number;
  remarks?: string;
};
// 创建字典修改参数DictEditParams
export type DictEditParams = {
  remarks?: string;
  createBy?: string;
  createDate?: string;
  updateBy?: string;
  updateDate?: string;
  delFlag?: string;
  flag?: string;
  businessId?: number;
  dictType?: String;
  dictName?: String;
  parentId?: String;
  dataId?: number;
  dictSort?: String;
  remark?: String;
  username?: String;
  types?: String;
};
export type DeptParams = {
  deptName?: string;
  status?: string;
};

export type MenuParams = {
  menuName?: string;
  status?: string;
};

export interface AccountListItem {
  id: string;
  account: string;
  email: string;
  nickname: string;
  role: number;
  createTime: string;
  remark: string;
  status: number;
}

export interface DeptListItem {
  id: string;
  orderNo: string;
  createTime: string;
  remark: string;
  status: number;
}

export interface MenuListItem {
  id: string;
  orderNo: string;
  createTime: string;
  status: number;
  icon: string;
  component: string;
  permission: string;
}

export interface RoleListItem {
  id: string;
  roleName: string;
  roleValue: string;
  status: number;
  orderNo: string;
  createTime: string;
}
// 创建字典列表参数
export interface DictListItem {
  id: string;
  beginTime: Date;
  endTime: Date;
  dictName: string;
  dictType: string;
  flag: number;
}
// 创建字典详情新增参数
export type DictDataAddParams = {
  dictName?: string;
  dictType?: string;
  dataId?: string;
  parentId?: string;
  status?: string;
  flag?: number;
  remarks?: string;
};
// 创建字典数据详情列表参数

export interface DictDataItem {
  businessId: number;
  createBy: string;
  createDate: string;
  cssClass: string;
  delFlag: string;
  dictLabel: string;
  dictSort: number;
  dictType: string;
  dictValue: string;
  flag: string;
  isDefault: string;
  listClass: string;
  remark: string;
  remarks: string;
  updateBy: string;
  updateDate: string;
}
/**
 * @description: Request list return value
 */
export type AccountListGetResultModel = BasicFetchResult<AccountListItem>;

export type DeptListGetResultModel = BasicFetchResult<DeptListItem>;

export type MenuListGetResultModel = BasicFetchResult<MenuListItem>;

export type RolePageListGetResultModel = BasicFetchResult<RoleListItem>;

export type RoleListGetResultModel = RoleListItem[];

//暴露Dict查询参数
export type DictPageListGetResultModel = BasicFetchResult<DictListItem>;

export type DictListGetResultModel = DictListItem[];

//暴露Dict路由跳转后查询参数
export type DictRouteListGetResultModel = BasicFetchResult<DictRouteParams>;

export type DictRouteModel = DictRouteParams[];
